@@ -1,3 +1,5 @@
+from asyncore import write
+from multiprocessing import Lock
 import os
 import time
 from time import sleep
@@ -9,23 +11,42 @@ from logging import *
 import threading
 import datetime
 import serial
-class yc_serial(serial):
+from queue import Queue
+import threading
+class yc_serial():
     def __init__(self,port,baudrate):
+        self.lock = threading.RLock()
         self.log = LOG("serial")
-        self.port = serial.Serial(port,baudrate)
-        if (self.port.is_open):
-            self.log.info("打开:",self.port.portstr)
+        self.q_receive = Queue()
+        self.port1 = serial.Serial(port,baudrate)
+        if (self.port1.is_open):
+            self.log.info("打开端口:%s成功"%port)
         else:
-            self.log.info("打开端口:%d失败"%port)
-        Creat_Thread(self.receivemsg)
+            self.log.info("打开端口:%s失败"%port)
+        # Creat_Thread(self.receivemsg)
 
+    def write(self,data):
+        self.lock.acquire()
+        self.port1.write(data)
+        self.lock.release()
     def receivemsg(self):
         while True:
-            size=self.port.in_waiting
+            size=self.port1.in_waiting
             if size:
-                self.recdata = self.port.read_all().decode('utf-8')
+                self.recdata = self.port1.readline().decode('utf-8').replace("\r","").replace("\n","")
                 if self.recdata != "":
-                    print("rec at", time.ctime(), '\n', str(self.recdata))
+                    self.log.info(str(self.recdata))
+                    self.q_receive.put(self.recdata)
+
+    def write_str(self,senddata:str):
+        senddata1 = senddata.encode('utf-8')
+        self.write(senddata1)
+        self.log.info("write->"+senddata)
+
+    def write_hex(self,senddata:list):
+        self.write(senddata)
+        self.log.info("write->"+str(senddata))
+
 class LOG(logging.Logger):
     def __init__(self,
                  name='root',
@@ -38,7 +59,7 @@ class LOG(logging.Logger):
             os.makedirs(filepath)
         super().__init__(name)
         self.setLevel(level)
-        fmt = logging.Formatter("%(asctime)s %(filename)s-%(lineno)d-%(levelname)s:     %(message)s", "%H:%M:%S")
+        fmt = logging.Formatter("%(asctime)s %(name)s-line:%(lineno)d-%(levelname)s:     %(message)s", "%H:%M:%S")
         file_handler = logging.FileHandler(file,encoding='utf-8')
         file_handler.setLevel(level)
         file_handler.setFormatter(fmt)
@@ -57,7 +78,7 @@ class LOG(logging.Logger):
         logger.info("Houston, we have a %s", "interesting problem", exc_info=1)
         """
         if self.isEnabledFor(INFO):
-            beep_on()
+            # beep_on()
             self._log(INFO, msg, args, **kwargs)
 
 def mkdir(path):
@@ -74,8 +95,8 @@ def get_cmd_result(cmd):
     # print(cmd)
     result = os.popen(cmd)
     res = result.read()
-    # for line in res.splitlines():
-    #     print (line)
+    for line in res.splitlines():
+        print (line)
     time.sleep(0.1)
     return res
 def xw_toExcel(data,excelname):  # xlsxwriter库储存数据到excel
